@@ -25,7 +25,6 @@
 #include <glib/gi18n.h>
 #include <packagekit-glib2/packagekit.h>
 
-#include "egg-debug.h"
 #include "egg-string.h"
 
 #include "gpk-enum.h"
@@ -56,6 +55,8 @@ static const PkEnumMatch enum_info_icon_name[] = {
 	{PK_INFO_ENUM_DOWNGRADING,		"pk-package-update"},
 	{PK_INFO_ENUM_PREPARING,		"dialog-information"},
 	{PK_INFO_ENUM_DECOMPRESSING,		"dialog-information"},
+	{PK_INFO_ENUM_TRUSTED,			"dialog-information"},
+	{PK_INFO_ENUM_UNTRUSTED,		"dialog-information"},
 	{0, NULL}
 };
 
@@ -177,6 +178,7 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES, "pk-package-add"},
 	{PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,	"pk-package-delete"},
 	{PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,	"pk-package-update"},
+	{PK_ROLE_ENUM_UPGRADE_SYSTEM,		"system-software-update"},
 	{0, NULL}
 };
 
@@ -287,7 +289,7 @@ gpk_media_type_enum_to_localised_text (PkMediaTypeEnum type)
 		text = _("media");
 		break;
 	default:
-		egg_warning ("Unknown media type");
+		g_warning ("Unknown media type");
 	}
 	return text;
 }
@@ -492,8 +494,14 @@ gpk_error_enum_to_localised_text (PkErrorEnum code)
 	case PK_ERROR_ENUM_INSTALL_ROOT_INVALID:
 		text = _("Install root is invalid");
 		break;
+	case PK_ERROR_ENUM_CANNOT_FETCH_SOURCES:
+		text = _("Cannot fetch install sources");
+		break;
+	case PK_ERROR_ENUM_CANCELLED_PRIORITY:
+		text = _("Rescheduled due to priority");
+		break;
 	default:
-		egg_warning ("Unknown error");
+		g_warning ("Unknown error");
 	}
 	return text;
 }
@@ -737,8 +745,14 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 	case PK_ERROR_ENUM_INSTALL_ROOT_INVALID:
 		text = _("The install root is invalid. Please contact your administrator.");
 		break;
+	case PK_ERROR_ENUM_CANNOT_FETCH_SOURCES:
+		text = _("The list of software sources could not be downloaded.");
+		break;
+	case PK_ERROR_ENUM_CANCELLED_PRIORITY:
+		text = _("The transaction has been cancelled and will be retried when the system is idle.");
+		break;
 	default:
-		egg_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
+		g_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
 			    "More information is available in the detailed report.");
 	}
 	return text;
@@ -771,7 +785,7 @@ gpk_restart_enum_to_localised_text_future (PkRestartEnum restart)
 		text = _("A restart will be required due to a security update.");
 		break;
 	default:
-		egg_warning ("restart unrecognised: %i", restart);
+		g_warning ("restart unrecognised: %i", restart);
 	}
 	return text;
 }
@@ -803,7 +817,7 @@ gpk_restart_enum_to_localised_text (PkRestartEnum restart)
 		text = _("A restart is required to remain secure.");
 		break;
 	default:
-		egg_warning ("restart unrecognised: %i", restart);
+		g_warning ("restart unrecognised: %i", restart);
 	}
 	return text;
 }
@@ -829,7 +843,7 @@ gpk_update_state_enum_to_localised_text (PkUpdateStateEnum state)
 		text = _("Testing");
 		break;
 	default:
-		egg_warning ("state unrecognised: %i", state);
+		g_warning ("state unrecognised: %i", state);
 	}
 	return text;
 }
@@ -891,7 +905,7 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 		text = _("Other updates have been held back");
 		break;
 	default:
-		egg_warning ("message unrecognised: %i", message);
+		g_warning ("message unrecognised: %i", message);
 	}
 	return text;
 }
@@ -1053,7 +1067,7 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		text = _("Copying files");
 		break;
 	default:
-		egg_warning ("status unrecognised: %s", pk_status_enum_to_text (status));
+		g_warning ("status unrecognised: %s", pk_status_enum_to_text (status));
 	}
 	return text;
 }
@@ -1095,7 +1109,7 @@ gpk_update_enum_to_localised_text (PkInfoEnum info, guint number)
 		text = g_strdup_printf (ngettext ("%i blocked update", "%i blocked updates", number), number);
 		break;
 	default:
-		egg_warning ("update info unrecognised: %s", pk_info_enum_to_text (info));
+		g_warning ("update info unrecognised: %s", pk_info_enum_to_text (info));
 	}
 	return text;
 }
@@ -1146,8 +1160,16 @@ gpk_info_enum_to_localised_text (PkInfoEnum info)
 		/* TRANSLATORS: The state of a package, i.e. not installed */
 		text = _("Available");
 		break;
+	case PK_INFO_ENUM_TRUSTED:
+		/* TRANSLATORS: The type of package */
+		text = _("Trusted");
+		break;
+	case PK_INFO_ENUM_UNTRUSTED:
+		/* TRANSLATORS: The type of package */
+		text = _("Untrusted");
+		break;
 	default:
-		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
+		g_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
 	return text;
 }
@@ -1197,7 +1219,7 @@ gpk_info_enum_to_localised_present (PkInfoEnum info)
 		text = _("Decompressing");
 		break;
 	default:
-		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
+		g_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
 	return text;
 }
@@ -1247,7 +1269,7 @@ gpk_info_enum_to_localised_past (PkInfoEnum info)
 		text = _("Decompressed");
 		break;
 	default:
-		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
+		g_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
 	return text;
 }
@@ -1400,8 +1422,12 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Simulating the update");
 		break;
+	case PK_ROLE_ENUM_UPGRADE_SYSTEM:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Upgrading system");
+		break;
 	default:
-		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
+		g_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
 	return text;
 }
@@ -1556,8 +1582,12 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Simulated the update");
 		break;
+	case PK_ROLE_ENUM_UPGRADE_SYSTEM:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Upgraded system");
+		break;
 	default:
-		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
+		g_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
 	return text;
 }
@@ -1711,7 +1741,7 @@ gpk_group_enum_to_localised_text (PkGroupEnum group)
 		text = _("Unknown group");
 		break;
 	default:
-		egg_warning ("group unrecognised: %i", group);
+		g_warning ("group unrecognised: %i", group);
 	}
 	return text;
 }
@@ -1794,7 +1824,7 @@ gpk_message_enum_to_icon_name (PkMessageEnum message)
 const gchar *
 gpk_info_status_enum_to_text (GpkInfoStatusEnum info)
 {
-	if (info >= PK_INFO_ENUM_LAST)
+	if ((PkInfoEnum)info >= PK_INFO_ENUM_LAST)
 		return gpk_info_enum_to_localised_past (info - PK_INFO_ENUM_LAST);
 	return gpk_info_enum_to_localised_present (info);
 }
@@ -1813,7 +1843,7 @@ gpk_info_status_enum_to_icon_name (GpkInfoStatusEnum info)
 		return "pk-package-installed";
 
 	/* use normal icon as a fallback */
-	if (info >= PK_INFO_ENUM_LAST)
+	if ((PkInfoEnum)info >= PK_INFO_ENUM_LAST)
 		return gpk_info_enum_to_icon_name (info - PK_INFO_ENUM_LAST);
 
 	/* regular PkInfoEnum */
