@@ -57,7 +57,21 @@ typedef enum {
 
 /* constants defined in previous versions */
 #if (!PK_CHECK_VERSION(0,6,11))
-#define PK_ROLE_ENUM_UPGRADE_SYSTEM					(PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES + 1)
+#define PK_ROLE_ENUM_UPGRADE_SYSTEM			G_MAXINT
+#define PK_ERROR_ENUM_CANNOT_FETCH_SOURCES		(PK_ERROR_ENUM_INSTALL_ROOT_INVALID+1)
+#endif
+
+#if (!PK_CHECK_VERSION(0,6,14))
+#define PK_ERROR_ENUM_CANCELLED_PRIORITY		(PK_ERROR_ENUM_CANNOT_FETCH_SOURCES+1)
+#endif
+
+#if (!PK_CHECK_VERSION(0,6,15))
+#define PK_INFO_ENUM_UNTRUSTED				(PK_INFO_ENUM_DECOMPRESSING+1)
+#define PK_INFO_ENUM_TRUSTED				(PK_INFO_ENUM_UNTRUSTED+1)
+#endif
+
+#if (!PK_CHECK_VERSION(0,6,16))
+#define PK_PROVIDES_ENUM_PLASMA_SERVICE			(PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER+1)
 #endif
 
 void		 gpk_enum_test				(gpointer	 data);
